@@ -9,7 +9,7 @@ use Data::Dump qw( dump );
 use Scalar::Util qw( blessed );
 use SWISH::Prog::Config;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 __PACKAGE__->mk_accessors(qw( aggregator ));
 
@@ -64,15 +64,18 @@ Overrides base SWISH::Prog::Class init() method.
 =cut
 
 # allow for short names. we map to class->new
-my %short = (
+my %ashort = (
     fs     => 'SWISH::Prog::Aggregator::FS',
     mail   => 'SWISH::Prog::Aggregator::Mail',
     dbi    => 'SWISH::Prog::Aggregator::DBI',
     spider => 'SWISH::Prog::Aggregator::Spider',
     object => 'SWISH::Prog::Aggregator::Object',
+);
+my %ishort = (
     native => 'SWISH::Prog::Indexer::Native',
     xapian => 'SWISH::Prog::Indexer::Xapian',
     ks     => 'SWISH::Prog::Indexer::KinoSearch',
+    dbi    => 'SWISH::Prog::Indexer::DBI',
 );
 
 sub init {
@@ -90,8 +93,8 @@ sub init {
     $indexer = $self->{indexer} || 'native';
     if ( !blessed($indexer) ) {
 
-        if ( exists $short{$indexer} ) {
-            $indexer = $short{$indexer};
+        if ( exists $ishort{$indexer} ) {
+            $indexer = $ishort{$indexer};
         }
 
         eval "require $indexer";
@@ -100,12 +103,8 @@ sub init {
         }
         $indexer = $indexer->new(
             debug    => $self->debug,
-            invindex => blessed( $self->{invindex} )
-            ? $self->{invindex}
-            : SWISH::Prog::InvIndex::Native->new(
-                invindex => $self->{invindex}
-            ),
-            verbose => $self->verbose
+            invindex => $self->{invindex},
+            verbose  => $self->verbose
         );
     }
     elsif ( !$indexer->isa('SWISH::Prog::Indexer') ) {
@@ -136,8 +135,8 @@ sub init {
     $aggregator = $self->{aggregator} || 'fs';
     if ( !blessed($aggregator) ) {
 
-        if ( exists $short{$aggregator} ) {
-            $aggregator = $short{$aggregator};
+        if ( exists $ashort{$aggregator} ) {
+            $aggregator = $ashort{$aggregator};
         }
 
         eval "require $aggregator";
